#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-CXIRlJGtDTvn5MspF0GXG
key:                  hedgehog-classes-0.2.5.4-CXIRlJGtDTvn5MspF0GXG
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  a5af0d5993cf7355b153d8b2be59cd46
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hedgehog-classes-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-CXIRlJGtDTvn5MspF0GXG
depends:
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4 base-4.18.2.1 binary-0.8.9.1
    comonad-5.0.10-EXUe6qWqQMj9EujznH0ooo containers-0.6.7
    hedgehog-1.5-LKZssJta7OwEs21qoR4c1J
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR
    primitive-0.9.1.0-9K5vR1Mi21T8XGVzI2tm4J
    semirings-0.7-Kz1SmgfuWoU8NkthjVZIdH
    silently-1.2.5.4-BeJQMFrht8zIosElyGUCP7 transformers-0.6.1.0
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    wl-pprint-annotated-0.1.0.1-9Rbuw0VzMjxW8jKocCbxo

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

